Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(955)

Unified Diff: third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h

Issue 2370703003: Validate internalformat/format/type for uploading DOM elements to texture (Closed)
Patch Set: fix extension Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
diff --git a/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h b/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
index df6ad14b3f1fc69bd9e17d4b9fb64718cabcf6db..7b44236a0ca87d2ff0cc78297e22e59ecf966d37 100644
--- a/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
+++ b/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
@@ -749,6 +749,7 @@ protected:
Vector<GLenum> m_syntheticErrors;
bool m_isWebGL2FormatsTypesAdded;
+ bool m_isWebGL2TexImageSourceFormatsTypesAdded;
bool m_isWebGL2InternalFormatsCopyTexImageAdded;
bool m_isOESTextureFloatFormatsTypesAdded;
bool m_isOESTextureHalfFloatFormatsTypesAdded;
@@ -756,9 +757,12 @@ protected:
bool m_isEXTsRGBFormatsTypesAdded;
std::set<GLenum> m_supportedInternalFormats;
+ std::set<GLenum> m_supportedTexImageSourceInternalFormats;
std::set<GLenum> m_supportedInternalFormatsCopyTexImage;
std::set<GLenum> m_supportedFormats;
+ std::set<GLenum> m_supportedTexImageSourceFormats;
std::set<GLenum> m_supportedTypes;
+ std::set<GLenum> m_supportedTexImageSourceTypes;
// Helpers for getParameter and others
ScriptValue getBooleanParameter(ScriptState*, GLenum);
@@ -859,7 +863,13 @@ protected:
// null. Otherwise, return the texture bound to the target.
WebGLTexture* validateTexture2DBinding(const char* functionName, GLenum target);
- // Helper function to check input internalformat/format/type for functions {copy}Tex{Sub}Image.
+ void addExtensionSupportedFormatsTypes();
+
+ // Helper function to check input internalformat/format/type for functions Tex{Sub}Image taking TexImageSource source data.
+ // Generates GL error and returns false if parameters are invalid.
+ bool validateTexImageSourceFormatAndType(const char* functionName, TexImageFunctionType, GLenum internalformat, GLenum format, GLenum type);
+
+ // Helper function to check input internalformat/format/type for functions Tex{Sub}Image.
// Generates GL error and returns false if parameters are invalid.
bool validateTexFuncFormatAndType(const char* functionName, TexImageFunctionType, GLenum internalformat, GLenum format, GLenum type, GLint level);
@@ -908,7 +918,7 @@ protected:
// Helper function to check input parameters for functions {copy}Tex{Sub}Image.
// Generates GL error and returns false if parameters are invalid.
- bool validateTexFuncParameters(const char* functionName, TexImageFunctionType, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type);
+ bool validateTexFuncParameters(const char* functionName, TexImageFunctionType, TexFuncValidationSourceType, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type);
enum NullDisposition {
NullAllowed,

Powered by Google App Engine
This is Rietveld 408576698